"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with an asycnhronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on.

    Args:
        job_id(str): The identifier that Amazon Translate generated for the job. The StartTextTranslationJob operation returns this identifier in its response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.text.translation_job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.text.translation_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="describe_text_translation_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the batch translation jobs that you have submitted.

    Args:
        filter_(Dict, optional): The parameters that specify which batch translation jobs to retrieve. Filters include job name, job status, and submission time. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.text.translation_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.text.translation_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="list_text_translation_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    output_data_config: Dict,
    data_access_role_arn: str,
    source_language_code: str,
    target_language_codes: List,
    client_token: str,
    job_name: str = None,
    terminology_names: List = None,
    parallel_data_names: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous batch translation job. Batch translation jobs can be used to translate large volumes of text across multiple documents at once. For more information, see async. Batch translation jobs can be described with the DescribeTextTranslationJob operation, listed with the ListTextTranslationJobs operation, and stopped with the StopTextTranslationJob operation.  Amazon Translate does not support batch translation of multiple source languages at once.

    Args:
        job_name(str, optional): The name of the batch translation job to be performed. Defaults to None.
        input_data_config(Dict): Specifies the format and S3 location of the input documents for the translation job.
        output_data_config(Dict): Specifies the S3 folder to which your job output will be saved. .
        data_access_role_arn(str): The Amazon Resource Name (ARN) of an AWS Identity Access and Management (IAM) role that grants Amazon Translate read access to your input data. For more nformation, see identity-and-access-management.
        source_language_code(str): The language code of the input language. For a list of language codes, see what-is-languages. Amazon Translate does not automatically detect a source language during batch translation jobs.
        target_language_codes(List): The language code of the output language.
        terminology_names(List, optional): The name of the terminology to use in the batch translation job. For a list of available terminologies, use the ListTerminologies operation. Defaults to None.
        parallel_data_names(List, optional): The names of the parallel data resources to use in the batch translation job. For a list of available parallel data resources, use the ListParallelData operation. Defaults to None.
        client_token(str): A unique identifier for the request. This token is auto-generated when using the Amazon Translate SDK.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.text.translation_job.start(
                ctx,
                input_data_config=value,
                output_data_config=value,
                data_access_role_arn=value,
                source_language_code=value,
                target_language_codes=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.text.translation_job.start input_data_config=value, output_data_config=value, data_access_role_arn=value, source_language_code=value, target_language_codes=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="start_text_translation_job",
        op_kwargs={
            "JobName": job_name,
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "DataAccessRoleArn": data_access_role_arn,
            "SourceLanguageCode": source_language_code,
            "TargetLanguageCodes": target_language_codes,
            "TerminologyNames": terminology_names,
            "ParallelDataNames": parallel_data_names,
            "ClientToken": client_token,
        },
    )


async def stop(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops an asynchronous batch translation job that is in progress. If the job's state is IN_PROGRESS, the job will be marked for termination and put into the STOP_REQUESTED state. If the job completes before it can be stopped, it is put into the COMPLETED state. Otherwise, the job is put into the STOPPED state. Asynchronous batch translation jobs are started with the StartTextTranslationJob operation. You can use the DescribeTextTranslationJob or ListTextTranslationJobs operations to get a batch translation job's JobId.

    Args:
        job_id(str): The job ID of the job to be stopped.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.translate.text.translation_job.stop(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.translate.text.translation_job.stop job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="translate",
        operation="stop_text_translation_job",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    repository: Dict,
    client_request_token: str = None,
    tags: Dict = None,
    kms_key_details: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Use to associate an AWS CodeCommit repository or a repostory managed by AWS CodeStar Connections with Amazon CodeGuru Reviewer. When you associate a repository, CodeGuru Reviewer reviews source code changes in the repository's pull requests and provides automatic recommendations. You can view recommendations using the CodeGuru Reviewer console. For more information, see Recommendations in Amazon CodeGuru Reviewer in the Amazon CodeGuru Reviewer User Guide.  If you associate a CodeCommit or S3 repository, it must be in the same AWS Region and AWS account where its CodeGuru Reviewer code reviews are configured. Bitbucket and GitHub Enterprise Server repositories are managed by AWS CodeStar Connections to connect to CodeGuru Reviewer. For more information, see Associate a repository in the Amazon CodeGuru Reviewer User Guide.    You cannot use the CodeGuru Reviewer SDK or the AWS CLI to associate a GitHub repository with Amazon CodeGuru Reviewer. To associate a GitHub repository, use the console. For more information, see Getting started with CodeGuru Reviewer in the CodeGuru Reviewer User Guide.

    Args:
        repository(Dict): The repository to associate.
        client_request_token(str, optional): Amazon CodeGuru Reviewer uses this value to prevent the accidental creation of duplicate repository associations if there are failures and retries. . Defaults to None.
        tags(Dict, optional):  An array of key-value pairs used to tag an associated repository. A tag is a custom attribute label with two parts:    A tag key (for example, CostCenter, Environment, Project, or Secret). Tag keys are case sensitive.   An optional field known as a tag value (for example, 111122223333, Production, or a team name). Omitting the tag value is the same as using an empty string. Like tag keys, tag values are case sensitive.  . Defaults to None.
        kms_key_details(Dict, optional): A KMSKeyDetails object that contains:   The encryption option for this repository association. It is either owned by AWS Key Management Service (KMS) (AWS_OWNED_CMK) or customer managed (CUSTOMER_MANAGED_CMK).   The ID of the AWS KMS key that is associated with this respository association.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.repository.init.associate(
                ctx, repository=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.repository.init.associate repository=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="associate_repository",
        op_kwargs={
            "Repository": repository,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
            "KMSKeyDetails": kms_key_details,
        },
    )


async def disassociate(hub, ctx, association_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the association between Amazon CodeGuru Reviewer and a repository.

    Args:
        association_arn(str):  The Amazon Resource Name (ARN) of the  RepositoryAssociation  object. You can retrieve this ARN by calling  ListRepositoryAssociations . .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.repository.init.disassociate(
                ctx, association_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.repository.init.disassociate association_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="disassociate_repository",
        op_kwargs={"AssociationArn": association_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def update(
    hub, ctx, cluster_arn: str, current_version: str, target_instance_type: str
) -> Dict:
    r"""
        **Autogenerated function**


        Updates EC2 instance type.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .
            current_version(str):
    The cluster version that you want to change. After this operation completes successfully, the cluster will have a new version.
    .
            target_instance_type(str):
    The Amazon MSK broker type that you want all of the brokers in this cluster to be.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.broker.type_.update(
                    ctx, cluster_arn=value, current_version=value, target_instance_type=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.broker.type.update cluster_arn=value, current_version=value, target_instance_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="update_broker_type",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "CurrentVersion": current_version,
            "TargetInstanceType": target_instance_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    egress: bool,
    network_acl_id: str,
    protocol: str,
    rule_action: str,
    rule_number: int,
    cidr_block: str = None,
    dry_run: bool = None,
    icmp_type_code: Dict = None,
    ipv6_cidr_block: str = None,
    port_range: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates an entry (a rule) in a network ACL with the specified rule number. Each network ACL has a set of numbered ingress rules and a separate set of numbered egress rules. When determining whether a packet should be allowed in or out of a subnet associated with the ACL, we process the entries in the ACL according to the rule numbers, in ascending order. Each network ACL has a set of ingress rules and a separate set of egress rules. We recommend that you leave room between the rule numbers (for example, 100, 110, 120, ...), and not number them one right after the other (for example, 101, 102, 103, ...). This makes it easier to add a rule between existing ones without having to renumber the rules. After you add an entry, you can't modify it; you must either replace it, or create an entry and delete the old one. For more information about network ACLs, see Network ACLs in the Amazon Virtual Private Cloud User Guide.

    Args:
        cidr_block(str, optional): The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24). We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        egress(bool): Indicates whether this is an egress rule (rule is applied to traffic leaving the subnet).
        icmp_type_code(Dict, optional): ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block. Defaults to None.
        ipv6_cidr_block(str, optional): The IPv6 network range to allow or deny, in CIDR notation (for example 2001:db8:1234:1a00::/64). Defaults to None.
        network_acl_id(str): The ID of the network ACL.
        port_range(Dict, optional): TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP). Defaults to None.
        protocol(str): The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
        rule_action(str): Indicates whether to allow or deny the traffic that matches the rule.
        rule_number(int): The rule number for the entry (for example, 100). ACL entries are processed in ascending order by rule number. Constraints: Positive integer from 1 to 32766. The range 32767 to 65535 is reserved for internal use.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.entry.create(
                ctx,
                egress=value,
                network_acl_id=value,
                protocol=value,
                rule_action=value,
                rule_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.entry.create egress=value, network_acl_id=value, protocol=value, rule_action=value, rule_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_network_acl_entry",
        op_kwargs={
            "CidrBlock": cidr_block,
            "DryRun": dry_run,
            "Egress": egress,
            "IcmpTypeCode": icmp_type_code,
            "Ipv6CidrBlock": ipv6_cidr_block,
            "NetworkAclId": network_acl_id,
            "PortRange": port_range,
            "Protocol": protocol,
            "RuleAction": rule_action,
            "RuleNumber": rule_number,
        },
    )


async def delete(
    hub, ctx, egress: bool, network_acl_id: str, rule_number: int, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified ingress or egress entry (rule) from the specified network ACL.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        egress(bool): Indicates whether the rule is an egress rule.
        network_acl_id(str): The ID of the network ACL.
        rule_number(int): The rule number of the entry to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.entry.delete(
                ctx, egress=value, network_acl_id=value, rule_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.entry.delete egress=value, network_acl_id=value, rule_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_network_acl_entry",
        op_kwargs={
            "DryRun": dry_run,
            "Egress": egress,
            "NetworkAclId": network_acl_id,
            "RuleNumber": rule_number,
        },
    )


async def replace(
    hub,
    ctx,
    egress: bool,
    network_acl_id: str,
    protocol: str,
    rule_action: str,
    rule_number: int,
    cidr_block: str = None,
    dry_run: bool = None,
    icmp_type_code: Dict = None,
    ipv6_cidr_block: str = None,
    port_range: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Replaces an entry (rule) in a network ACL. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.

    Args:
        cidr_block(str, optional): The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24). Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        egress(bool): Indicates whether to replace the egress rule. Default: If no value is specified, we replace the ingress rule.
        icmp_type_code(Dict, optional): ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block. Defaults to None.
        ipv6_cidr_block(str, optional): The IPv6 network range to allow or deny, in CIDR notation (for example 2001:bd8:1234:1a00::/64). Defaults to None.
        network_acl_id(str): The ID of the ACL.
        port_range(Dict, optional): TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP). Defaults to None.
        protocol(str): The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
        rule_action(str): Indicates whether to allow or deny the traffic that matches the rule.
        rule_number(int): The rule number of the entry to replace.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.acl.entry.replace(
                ctx,
                egress=value,
                network_acl_id=value,
                protocol=value,
                rule_action=value,
                rule_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.acl.entry.replace egress=value, network_acl_id=value, protocol=value, rule_action=value, rule_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="replace_network_acl_entry",
        op_kwargs={
            "CidrBlock": cidr_block,
            "DryRun": dry_run,
            "Egress": egress,
            "IcmpTypeCode": icmp_type_code,
            "Ipv6CidrBlock": ipv6_cidr_block,
            "NetworkAclId": network_acl_id,
            "PortRange": port_range,
            "Protocol": protocol,
            "RuleAction": rule_action,
            "RuleNumber": rule_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the run, given the run ARN.  Deleting this resource does not stop an in-progress run.

    Args:
        arn(str): The Amazon Resource Name (ARN) for the run to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.run.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.run.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="delete_run", op_kwargs={"arn": arn}
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a run.

    Args:
        arn(str): The run's ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.run.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.run.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="get_run", op_kwargs={"arn": arn}
    )


async def schedule(
    hub,
    ctx,
    project_arn: str,
    test: Dict,
    app_arn: str = None,
    device_pool_arn: str = None,
    device_selection_configuration: Dict = None,
    name: str = None,
    configuration: Dict = None,
    execution_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Schedules a run.

    Args:
        project_arn(str): The ARN of the project for the run to be scheduled.
        app_arn(str, optional): The ARN of an application package to run tests against, created with CreateUpload. See ListUploads. Defaults to None.
        device_pool_arn(str, optional): The ARN of the device pool for the run to be scheduled. Defaults to None.
        device_selection_configuration(Dict, optional): The filter criteria used to dynamically select a set of devices for a test run and the maximum number of devices to be included in the run. Either  devicePoolArn  or  deviceSelectionConfiguration  is required in a request. Defaults to None.
        name(str, optional): The name for the run to be scheduled. Defaults to None.
        test(Dict): Information about the test for the run to be scheduled.
        configuration(Dict, optional): Information about the settings for the run to be scheduled. Defaults to None.
        execution_configuration(Dict, optional): Specifies configuration information about a test run, such as the execution timeout (in minutes). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.run.schedule(ctx, project_arn=value, test=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.run.schedule project_arn=value, test=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="schedule_run",
        op_kwargs={
            "projectArn": project_arn,
            "appArn": app_arn,
            "devicePoolArn": device_pool_arn,
            "deviceSelectionConfiguration": device_selection_configuration,
            "name": name,
            "test": test,
            "configuration": configuration,
            "executionConfiguration": execution_configuration,
        },
    )


async def stop(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Initiates a stop request for the current test run. AWS Device Farm immediately stops the run on devices where tests have not started. You are not billed for these devices. On devices where tests have started executing, setup suite and teardown suite tests run to completion on those devices. You are billed for setup, teardown, and any tests that were in progress or already completed.

    Args:
        arn(str): Represents the Amazon Resource Name (ARN) of the Device Farm run to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.run.stop(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.run.stop arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="devicefarm", operation="stop_run", op_kwargs={"arn": arn}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, voice_connector_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the proxy configuration from the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.proxy.delete(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.proxy.delete voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_voice_connector_proxy",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the proxy configuration details for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.proxy.get(ctx, voice_connector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.proxy.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_proxy",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def put(
    hub,
    ctx,
    voice_connector_id: str,
    default_session_expiry_minutes: int,
    phone_number_pool_countries: List,
    fall_back_phone_number: str = None,
    disabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Puts the specified proxy configuration to the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime voice connector ID.
        default_session_expiry_minutes(int): The default number of minutes allowed for proxy sessions.
        phone_number_pool_countries(List): The countries for proxy phone numbers to be selected from.
        fall_back_phone_number(str, optional): The phone number to route calls to after a proxy session expires. Defaults to None.
        disabled(bool, optional): When true, stops proxy sessions from being created on the specified Amazon Chime Voice Connector. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.proxy.put(
                ctx,
                voice_connector_id=value,
                default_session_expiry_minutes=value,
                phone_number_pool_countries=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.proxy.put voice_connector_id=value, default_session_expiry_minutes=value, phone_number_pool_countries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_voice_connector_proxy",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "DefaultSessionExpiryMinutes": default_session_expiry_minutes,
            "PhoneNumberPoolCountries": phone_number_pool_countries,
            "FallBackPhoneNumber": fall_back_phone_number,
            "Disabled": disabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(
    hub,
    ctx,
    username: str,
    user_pool_id: str,
    sms_mfa_settings: Dict = None,
    software_token_mfa_settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the user's multi-factor authentication (MFA) preference, including which MFA options are enabled and if any are preferred. Only one factor can be set as preferred. The preferred MFA factor will be used to authenticate a user if multiple factors are enabled. If multiple options are enabled and no preference is set, a challenge to choose an MFA option will be returned during sign in.

    Args:
        sms_mfa_settings(Dict, optional): The SMS text message MFA settings. Defaults to None.
        software_token_mfa_settings(Dict, optional): The time-based one-time password software token MFA settings. Defaults to None.
        username(str): The user pool username or alias.
        user_pool_id(str): The user pool ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.set_user.mfa_preference.admin(
                ctx, username=value, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.set_user.mfa_preference.admin username=value, user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_set_user_mfa_preference",
        op_kwargs={
            "SMSMfaSettings": sms_mfa_settings,
            "SoftwareTokenMfaSettings": software_token_mfa_settings,
            "Username": username,
            "UserPoolId": user_pool_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def detect(hub, ctx, stack_name: str, logical_resource_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Detects whether a stack's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters. For each resource in the stack that supports drift detection, CloudFormation compares the actual configuration of the resource with its expected template configuration. Only resource properties explicitly defined in the stack template are checked for drift. A stack is considered to have drifted if one or more of its resources differ from their expected template configurations. For more information, see Detecting Unregulated Configuration Changes to Stacks and Resources. Use DetectStackDrift to detect drift on all supported resources for a given stack, or DetectStackResourceDrift to detect drift on individual resources. For a list of stack resources that currently support drift detection, see Resources that Support Drift Detection.  DetectStackDrift can take up to several minutes, depending on the number of resources contained within the stack. Use DescribeStackDriftDetectionStatus to monitor the progress of a detect stack drift operation. Once the drift detection operation has completed, use DescribeStackResourceDrifts to return drift information about the stack and its resources. When detecting drift on a stack, CloudFormation does not detect drift on any nested stacks belonging to that stack. Perform DetectStackDrift directly on the nested stack itself.

    Args:
        stack_name(str): The name of the stack for which you want to detect drift. .
        logical_resource_ids(List, optional): The logical names of any resources you want to use as filters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.drift.init.detect(ctx, stack_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.drift.init.detect stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="detect_stack_drift",
        op_kwargs={"StackName": stack_name, "LogicalResourceIds": logical_resource_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, certificate_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags that have been applied to the ACM certificate. Use the certificate's Amazon Resource Name (ARN) to specify the certificate. To add a tag to an ACM certificate, use the AddTagsToCertificate action. To delete a tag, use the RemoveTagsFromCertificate action.

    Args:
        certificate_arn(str): String that contains the ARN of the ACM certificate for which you want to list the tags. This must have the following form:  arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012  For more information about ARNs, see Amazon Resource Names (ARNs).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.tags.for_certificate.list(ctx, certificate_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.tags.for_certificate.list certificate_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="list_tags_for_certificate",
        op_kwargs={"CertificateArn": certificate_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    stream_name: str = None,
    stream_arn: str = None,
    playback_mode: str = None,
    hls_fragment_selector: Dict = None,
    container_format: str = None,
    discontinuity_mode: str = None,
    display_fragment_timestamp: str = None,
    expires: int = None,
    max_media_playlist_fragment_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an HTTP Live Streaming (HLS) URL for the stream. You can then open the URL in a browser or media player to view the stream contents. Both the StreamName and the StreamARN parameters are optional, but you must specify either the StreamName or the StreamARN when invoking this API operation. An Amazon Kinesis video stream has the following requirements for providing data through HLS:   The media must contain h.264 or h.265 encoded video and, optionally, AAC encoded audio. Specifically, the codec ID of track 1 should be V_MPEG/ISO/AVC (for h.264) or V_MPEG/ISO/HEVC (for h.265). Optionally, the codec ID of track 2 should be A_AAC.   Data retention must be greater than 0.   The video track of each fragment must contain codec private data in the Advanced Video Coding (AVC) for H.264 format or HEVC for H.265 format (MPEG-4 specification ISO/IEC 14496-15). For information about adapting stream data to a given format, see NAL Adaptation Flags.   The audio track (if present) of each fragment must contain codec private data in the AAC format (AAC specification ISO/IEC 13818-7).   Kinesis Video Streams HLS sessions contain fragments in the fragmented MPEG-4 form (also called fMP4 or CMAF) or the MPEG-2 form (also called TS chunks, which the HLS specification also supports). For more information about HLS fragment types, see the HLS specification. The following procedure shows how to use HLS with Kinesis Video Streams:   Get an endpoint using GetDataEndpoint, specifying GET_HLS_STREAMING_SESSION_URL for the APIName parameter.   Retrieve the HLS URL using GetHLSStreamingSessionURL. Kinesis Video Streams creates an HLS streaming session to be used for accessing content in a stream using the HLS protocol. GetHLSStreamingSessionURL returns an authenticated URL (that includes an encrypted session token) for the session's HLS master playlist (the root resource needed for streaming with HLS).  Don't share or store this token where an unauthorized entity could access it. The token provides access to the content of the stream. Safeguard the token with the same measures that you would use with your AWS credentials.  The media that is made available through the playlist consists only of the requested stream, time range, and format. No other media data (such as frames outside the requested window or alternate bitrates) is made available.   Provide the URL (containing the encrypted session token) for the HLS master playlist to a media player that supports the HLS protocol. Kinesis Video Streams makes the HLS media playlist, initialization fragment, and media fragments available through the master playlist URL. The initialization fragment contains the codec private data for the stream, and other data needed to set up the video or audio decoder and renderer. The media fragments contain H.264-encoded video frames or AAC-encoded audio samples.   The media player receives the authenticated URL and requests stream metadata and media data normally. When the media player requests data, it calls the following actions:    GetHLSMasterPlaylist: Retrieves an HLS master playlist, which contains a URL for the GetHLSMediaPlaylist action for each track, and additional metadata for the media player, including estimated bitrate and resolution.    GetHLSMediaPlaylist: Retrieves an HLS media playlist, which contains a URL to access the MP4 initialization fragment with the GetMP4InitFragment action, and URLs to access the MP4 media fragments with the GetMP4MediaFragment actions. The HLS media playlist also contains metadata about the stream that the player needs to play it, such as whether the PlaybackMode is LIVE or ON_DEMAND. The HLS media playlist is typically static for sessions with a PlaybackType of ON_DEMAND. The HLS media playlist is continually updated with new fragments for sessions with a PlaybackType of LIVE. There is a distinct HLS media playlist for the video track and the audio track (if applicable) that contains MP4 media URLs for the specific track.     GetMP4InitFragment: Retrieves the MP4 initialization fragment. The media player typically loads the initialization fragment before loading any media fragments. This fragment contains the "fytp" and "moov" MP4 atoms, and the child atoms that are needed to initialize the media player decoder. The initialization fragment does not correspond to a fragment in a Kinesis video stream. It contains only the codec private data for the stream and respective track, which the media player needs to decode the media frames.    GetMP4MediaFragment: Retrieves MP4 media fragments. These fragments contain the "moof" and "mdat" MP4 atoms and their child atoms, containing the encoded fragment's media frames and their timestamps.   After the first media fragment is made available in a streaming session, any fragments that don't contain the same codec private data cause an error to be returned when those different media fragments are loaded. Therefore, the codec private data should not change between fragments in a session. This also means that the session fails if the fragments in a stream change from having only video to having both audio and video.  Data retrieved with this action is billable. See Pricing for details.    GetTSFragment: Retrieves MPEG TS fragments containing both initialization and media data for all tracks in the stream.  If the ContainerFormat is MPEG_TS, this API is used instead of GetMP4InitFragment and GetMP4MediaFragment to retrieve stream media.  Data retrieved with this action is billable. For more information, see Kinesis Video Streams pricing.     A streaming session URL must not be shared between players. The service might throttle a session if multiple media players are sharing it. For connection limits, see Kinesis Video Streams Limits. You can monitor the amount of data that the media player consumes by monitoring the GetMP4MediaFragment.OutgoingBytes Amazon CloudWatch metric. For information about using CloudWatch to monitor Kinesis Video Streams, see Monitoring Kinesis Video Streams. For pricing information, see Amazon Kinesis Video Streams Pricing and AWS Pricing. Charges for both HLS sessions and outgoing AWS data apply. For more information about HLS, see HTTP Live Streaming on the Apple Developer site.  If an error is thrown after invoking a Kinesis Video Streams archived media API, in addition to the HTTP status code and the response body, it includes the following pieces of information:     x-amz-ErrorType HTTP header – contains a more specific error type in addition to what the HTTP status code provides.     x-amz-RequestId HTTP header – if you want to report an issue to AWS, the support team can better diagnose the problem if given the Request Id.   Both the HTTP status code and the ErrorType header can be utilized to make programmatic decisions about whether errors are retry-able and under what conditions, as well as provide information on what actions the client programmer might need to take in order to successfully try again. For more information, see the Errors section at the bottom of this topic, as well as Common Errors.

    Args:
        stream_name(str, optional): The name of the stream for which to retrieve the HLS master playlist URL. You must specify either the StreamName or the StreamARN. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream for which to retrieve the HLS master playlist URL. You must specify either the StreamName or the StreamARN. Defaults to None.
        playback_mode(str, optional): Whether to retrieve live, live replay, or archived, on-demand data. Features of the three types of sessions include the following:     LIVE : For sessions of this type, the HLS media playlist is continually updated with the latest fragments as they become available. We recommend that the media player retrieve a new playlist on a one-second interval. When this type of session is played in a media player, the user interface typically displays a "live" notification, with no scrubber control for choosing the position in the playback window to display.  In LIVE mode, the newest available fragments are included in an HLS media playlist, even if there is a gap between fragments (that is, if a fragment is missing). A gap like this might cause a media player to halt or cause a jump in playback. In this mode, fragments are not added to the HLS media playlist if they are older than the newest fragment in the playlist. If the missing fragment becomes available after a subsequent fragment is added to the playlist, the older fragment is not added, and the gap is not filled.      LIVE_REPLAY : For sessions of this type, the HLS media playlist is updated similarly to how it is updated for LIVE mode except that it starts by including fragments from a given start time. Instead of fragments being added as they are ingested, fragments are added as the duration of the next fragment elapses. For example, if the fragments in the session are two seconds long, then a new fragment is added to the media playlist every two seconds. This mode is useful to be able to start playback from when an event is detected and continue live streaming media that has not yet been ingested as of the time of the session creation. This mode is also useful to stream previously archived media without being limited by the 1,000 fragment limit in the ON_DEMAND mode.      ON_DEMAND : For sessions of this type, the HLS media playlist contains all the fragments for the session, up to the number that is specified in MaxMediaPlaylistFragmentResults. The playlist must be retrieved only once for each session. When this type of session is played in a media player, the user interface typically displays a scrubber control for choosing the position in the playback window to display.   In all playback modes, if FragmentSelectorType is PRODUCER_TIMESTAMP, and if there are multiple fragments with the same start timestamp, the fragment that has the largest fragment number (that is, the newest fragment) is included in the HLS media playlist. The other fragments are not included. Fragments that have different timestamps but have overlapping durations are still included in the HLS media playlist. This can lead to unexpected behavior in the media player. The default is LIVE. Defaults to None.
        hls_fragment_selector(Dict, optional): The time range of the requested fragment and the source of the timestamps. This parameter is required if PlaybackMode is ON_DEMAND or LIVE_REPLAY. This parameter is optional if PlaybackMode is LIVE. If PlaybackMode is LIVE, the FragmentSelectorType can be set, but the TimestampRange should not be set. If PlaybackMode is ON_DEMAND or LIVE_REPLAY, both FragmentSelectorType and TimestampRange must be set. Defaults to None.
        container_format(str, optional): Specifies which format should be used for packaging the media. Specifying the FRAGMENTED_MP4 container format packages the media into MP4 fragments (fMP4 or CMAF). This is the recommended packaging because there is minimal packaging overhead. The other container format option is MPEG_TS. HLS has supported MPEG TS chunks since it was released and is sometimes the only supported packaging on older HLS players. MPEG TS typically has a 5-25 percent packaging overhead. This means MPEG TS typically requires 5-25 percent more bandwidth and cost than fMP4. The default is FRAGMENTED_MP4. Defaults to None.
        discontinuity_mode(str, optional): Specifies when flags marking discontinuities between fragments are added to the media playlists. Media players typically build a timeline of media content to play, based on the timestamps of each fragment. This means that if there is any overlap or gap between fragments (as is typical if HLSFragmentSelector is set to SERVER_TIMESTAMP), the media player timeline will also have small gaps between fragments in some places, and will overwrite frames in other places. Gaps in the media player timeline can cause playback to stall and overlaps can cause playback to be jittery. When there are discontinuity flags between fragments, the media player is expected to reset the timeline, resulting in the next fragment being played immediately after the previous fragment.  The following modes are supported:    ALWAYS: a discontinuity marker is placed between every fragment in the HLS media playlist. It is recommended to use a value of ALWAYS if the fragment timestamps are not accurate.    NEVER: no discontinuity markers are placed anywhere. It is recommended to use a value of NEVER to ensure the media player timeline most accurately maps to the producer timestamps.     ON_DISCONTINUITY: a discontinuity marker is placed between fragments that have a gap or overlap of more than 50 milliseconds. For most playback scenarios, it is recommended to use a value of ON_DISCONTINUITY so that the media player timeline is only reset when there is a significant issue with the media timeline (e.g. a missing fragment).   The default is ALWAYS when HLSFragmentSelector is set to SERVER_TIMESTAMP, and NEVER when it is set to PRODUCER_TIMESTAMP. Defaults to None.
        display_fragment_timestamp(str, optional): Specifies when the fragment start timestamps should be included in the HLS media playlist. Typically, media players report the playhead position as a time relative to the start of the first fragment in the playback session. However, when the start timestamps are included in the HLS media playlist, some media players might report the current playhead as an absolute time based on the fragment timestamps. This can be useful for creating a playback experience that shows viewers the wall-clock time of the media. The default is NEVER. When HLSFragmentSelector is SERVER_TIMESTAMP, the timestamps will be the server start timestamps. Similarly, when HLSFragmentSelector is PRODUCER_TIMESTAMP, the timestamps will be the producer start timestamps. . Defaults to None.
        expires(int, optional): The time in seconds until the requested session expires. This value can be between 300 (5 minutes) and 43200 (12 hours). When a session expires, no new calls to GetHLSMasterPlaylist, GetHLSMediaPlaylist, GetMP4InitFragment, GetMP4MediaFragment, or GetTSFragment can be made for that session. The default is 300 (5 minutes). Defaults to None.
        max_media_playlist_fragment_results(int, optional): The maximum number of fragments that are returned in the HLS media playlists. When the PlaybackMode is LIVE, the most recent fragments are returned up to this value. When the PlaybackMode is ON_DEMAND, the oldest fragments are returned, up to this maximum number. When there are a higher number of fragments available in a live HLS media playlist, video players often buffer content before starting playback. Increasing the buffer size increases the playback latency, but it decreases the likelihood that rebuffering will occur during playback. We recommend that a live HLS media playlist have a minimum of 3 fragments and a maximum of 10 fragments. The default is 5 fragments if PlaybackMode is LIVE or LIVE_REPLAY, and 1,000 if PlaybackMode is ON_DEMAND.  The maximum value of 5,000 fragments corresponds to more than 80 minutes of video on streams with 1-second fragments, and more than 13 hours of video on streams with 10-second fragments. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis_video_archived_media.hls_streaming_session_url.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis_video_archived_media.hls_streaming_session_url.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis-video-archived-media",
        operation="get_hls_streaming_session_url",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "PlaybackMode": playback_mode,
            "HLSFragmentSelector": hls_fragment_selector,
            "ContainerFormat": container_format,
            "DiscontinuityMode": discontinuity_mode,
            "DisplayFragmentTimestamp": display_fragment_timestamp,
            "Expires": expires,
            "MaxMediaPlaylistFragmentResults": max_media_playlist_fragment_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, instance_arn: str, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates a set of tags with a specified resource.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        resource_arn(str): The ARN of the resource with the tags to be listed.
        tags(List): A set of key-value pairs that are used to manage the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.resource.tag(
                ctx, instance_arn=value, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.resource.tag instance_arn=value, resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="tag_resource",
        op_kwargs={
            "InstanceArn": instance_arn,
            "ResourceArn": resource_arn,
            "Tags": tags,
        },
    )


async def untag(hub, ctx, instance_arn: str, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a set of tags from a specified resource.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        resource_arn(str): The ARN of the resource with the tags to be listed.
        tag_keys(List): The keys of tags that are attached to the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.resource.untag(
                ctx, instance_arn=value, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.resource.untag instance_arn=value, resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="untag_resource",
        op_kwargs={
            "InstanceArn": instance_arn,
            "ResourceArn": resource_arn,
            "TagKeys": tag_keys,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def register(
    hub, ctx, client_name: str, client_type: str, scopes: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a client with AWS SSO. This allows clients to initiate device authorization. The output should be persisted for reuse through many authentication requests.

    Args:
        client_name(str): The friendly name of the client.
        client_type(str): The type of client. The service supports only public as a client type. Anything other than public will be rejected by the service.
        scopes(List, optional): The list of scopes that are defined by the client. Upon authorization, this list is used to restrict permissions when granting an access token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_oidc.client.register(
                ctx, client_name=value, client_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_oidc.client.register client_name=value, client_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-oidc",
        operation="register_client",
        op_kwargs={
            "clientName": client_name,
            "clientType": client_type,
            "scopes": scopes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, account_id: str, vault_name: str, archive_id: str) -> None:
    r"""
    **Autogenerated function**

    This operation deletes an archive from a vault. Subsequent requests to initiate a retrieval of this archive will fail. Archive retrievals that are in progress for this archive ID may or may not succeed according to the following scenarios:   If the archive retrieval job is actively preparing the data for download when Amazon S3 Glacier receives the delete archive request, the archival retrieval operation might fail.   If the archive retrieval job has successfully prepared the archive for download when Amazon S3 Glacier receives the delete archive request, you will be able to download the output.   This operation is idempotent. Attempting to delete an already-deleted archive does not result in an error. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For conceptual information and underlying REST API, see Deleting an Archive in Amazon Glacier and Delete Archive in the Amazon Glacier Developer Guide.

    Args:
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID.
        vault_name(str): The name of the vault.
        archive_id(str): The ID of the archive to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.archive.delete(
                ctx, account_id=value, vault_name=value, archive_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.archive.delete account_id=value, vault_name=value, archive_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="delete_archive",
        op_kwargs={
            "accountId": account_id,
            "vaultName": vault_name,
            "archiveId": archive_id,
        },
    )


async def upload(
    hub,
    ctx,
    vault_name: str,
    account_id: str,
    archive_description: str = None,
    checksum: str = None,
    body: bytes = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation adds an archive to a vault. This is a synchronous operation, and for a successful upload, your data is durably persisted. Amazon S3 Glacier returns the archive ID in the x-amz-archive-id header of the response.  You must use the archive ID to access your data in Amazon S3 Glacier. After you upload an archive, you should save the archive ID returned so that you can retrieve or delete the archive later. Besides saving the archive ID, you can also index it and give it a friendly name to allow for better searching. You can also use the optional archive description field to specify how the archive is referred to in an external index of archives, such as you might create in Amazon DynamoDB. You can also get the vault inventory to obtain a list of archive IDs in a vault. For more information, see InitiateJob.  You must provide a SHA256 tree hash of the data you are uploading. For information about computing a SHA256 tree hash, see Computing Checksums.  You can optionally specify an archive description of up to 1,024 printable ASCII characters. You can get the archive description when you either retrieve the archive or get the vault inventory. For more information, see InitiateJob. Amazon Glacier does not interpret the description in any way. An archive description does not need to be unique. You cannot use the description to retrieve or sort the archive list.  Archives are immutable. After you upload an archive, you cannot edit the archive or its description. An AWS account has full permission to perform all operations (actions). However, AWS Identity and Access Management (IAM) users don't have any permissions by default. You must grant them explicit permission to perform specific actions. For more information, see Access Control Using AWS Identity and Access Management (IAM).  For conceptual information and underlying REST API, see Uploading an Archive in Amazon Glacier and Upload Archive in the Amazon Glacier Developer Guide.

    Args:
        vault_name(str): The name of the vault.
        account_id(str): The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon S3 Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens ('-') in the ID. .
        archive_description(str, optional): The optional description of the archive you are uploading. Defaults to None.
        checksum(str, optional): The SHA256 tree hash of the data being uploaded. Defaults to None.
        body(bytes, optional): The data to upload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.archive.upload(ctx, vault_name=value, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.archive.upload vault_name=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="upload_archive",
        op_kwargs={
            "vaultName": vault_name,
            "accountId": account_id,
            "archiveDescription": archive_description,
            "checksum": checksum,
            "body": body,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def export(
    hub,
    ctx,
    table_arn: str,
    s3_bucket: str,
    export_time: str = None,
    client_token: str = None,
    s3_bucket_owner: str = None,
    s3_prefix: str = None,
    s3_sse_algorithm: str = None,
    s3_sse_kms_key_id: str = None,
    export_format: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports table data to an S3 bucket. The table must have point in time recovery enabled, and you can export data from any time within the point in time recovery window.

    Args:
        table_arn(str): The Amazon Resource Name (ARN) associated with the table to export.
        export_time(str, optional): Time in the past from which to export table data. The table export will be a snapshot of the table's state at this point in time. Defaults to None.
        client_token(str, optional): Providing a ClientToken makes the call to ExportTableToPointInTimeInput idempotent, meaning that multiple identical calls have the same effect as one single call. A client token is valid for 8 hours after the first request that uses it is completed. After 8 hours, any request with the same client token is treated as a new request. Do not resubmit the same request with the same client token for more than 8 hours, or the result might not be idempotent. If you submit a request with the same client token but a change in other parameters within the 8-hour idempotency window, DynamoDB returns an IdempotentParameterMismatch exception. Defaults to None.
        s3_bucket(str): The name of the Amazon S3 bucket to export the snapshot to.
        s3_bucket_owner(str, optional): The ID of the AWS account that owns the bucket the export will be stored in. Defaults to None.
        s3_prefix(str, optional): The Amazon S3 bucket prefix to use as the file name and path of the exported snapshot. Defaults to None.
        s3_sse_algorithm(str, optional): Type of encryption used on the bucket where export data will be stored. Valid values for S3SseAlgorithm are:    AES256 - server-side encryption with Amazon S3 managed keys    KMS - server-side encryption with AWS KMS managed keys  . Defaults to None.
        s3_sse_kms_key_id(str, optional): The ID of the AWS KMS managed key used to encrypt the S3 bucket where export data will be stored (if applicable). Defaults to None.
        export_format(str, optional): The format for the exported data. Valid values for ExportFormat are DYNAMODB_JSON or ION. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.to_point_in_time.export(
                ctx, table_arn=value, s3_bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.to_point_in_time.export table_arn=value, s3_bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="export_table_to_point_in_time",
        op_kwargs={
            "TableArn": table_arn,
            "ExportTime": export_time,
            "ClientToken": client_token,
            "S3Bucket": s3_bucket,
            "S3BucketOwner": s3_bucket_owner,
            "S3Prefix": s3_prefix,
            "S3SseAlgorithm": s3_sse_algorithm,
            "S3SseKmsKeyId": s3_sse_kms_key_id,
            "ExportFormat": export_format,
        },
    )


async def restore(
    hub,
    ctx,
    target_table_name: str,
    source_table_arn: str = None,
    source_table_name: str = None,
    use_latest_restorable_time: bool = None,
    restore_date_time: str = None,
    billing_mode_override: str = None,
    global_secondary_index_override: List = None,
    local_secondary_index_override: List = None,
    provisioned_throughput_override: Dict = None,
    sse_specification_override: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Restores the specified table to the specified point in time within EarliestRestorableDateTime and LatestRestorableDateTime. You can restore your table to any point in time during the last 35 days. Any number of users can execute up to 4 concurrent restores (any type of restore) in a given account.   When you restore using point in time recovery, DynamoDB restores your table data to the state based on the selected date and time (day:hour:minute:second) to a new table.   Along with data, the following are also included on the new restored table using point in time recovery:    Global secondary indexes (GSIs)   Local secondary indexes (LSIs)   Provisioned read and write capacity   Encryption settings   All these settings come from the current settings of the source table at the time of restore.     You must manually set up the following on the restored table:   Auto scaling policies   IAM policies   Amazon CloudWatch metrics and alarms   Tags   Stream settings   Time to Live (TTL) settings   Point in time recovery settings

    Args:
        source_table_arn(str, optional): The DynamoDB table that will be restored. This value is an Amazon Resource Name (ARN). Defaults to None.
        source_table_name(str, optional): Name of the source table that is being restored. Defaults to None.
        target_table_name(str): The name of the new table to which it must be restored to.
        use_latest_restorable_time(bool, optional): Restore the table to the latest possible time. LatestRestorableDateTime is typically 5 minutes before the current time. . Defaults to None.
        restore_date_time(str, optional): Time in the past to restore the table to. Defaults to None.
        billing_mode_override(str, optional): The billing mode of the restored table. Defaults to None.
        global_secondary_index_override(List, optional): List of global secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore. Defaults to None.
        local_secondary_index_override(List, optional): List of local secondary indexes for the restored table. The indexes provided should match existing secondary indexes. You can choose to exclude some or all of the indexes at the time of restore. Defaults to None.
        provisioned_throughput_override(Dict, optional): Provisioned throughput settings for the restored table. Defaults to None.
        sse_specification_override(Dict, optional): The new server-side encryption settings for the restored table. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.to_point_in_time.restore(
                ctx, target_table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.to_point_in_time.restore target_table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="restore_table_to_point_in_time",
        op_kwargs={
            "SourceTableArn": source_table_arn,
            "SourceTableName": source_table_name,
            "TargetTableName": target_table_name,
            "UseLatestRestorableTime": use_latest_restorable_time,
            "RestoreDateTime": restore_date_time,
            "BillingModeOverride": billing_mode_override,
            "GlobalSecondaryIndexOverride": global_secondary_index_override,
            "LocalSecondaryIndexOverride": local_secondary_index_override,
            "ProvisionedThroughputOverride": provisioned_throughput_override,
            "SSESpecificationOverride": sse_specification_override,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    distribution_name: str,
    origin: Dict,
    default_cache_behavior: Dict,
    bundle_id: str,
    cache_behavior_settings: Dict = None,
    cache_behaviors: List = None,
    ip_address_type: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Lightsail content delivery network (CDN) distribution. A distribution is a globally distributed network of caching servers that improve the performance of your website or web application hosted on a Lightsail instance. For more information, see Content delivery networks in Amazon Lightsail.

    Args:
        distribution_name(str): The name for the distribution.
        origin(Dict): An object that describes the origin resource for the distribution, such as a Lightsail instance or load balancer. The distribution pulls, caches, and serves content from the origin.
        default_cache_behavior(Dict): An object that describes the default cache behavior for the distribution.
        cache_behavior_settings(Dict, optional): An object that describes the cache behavior settings for the distribution. Defaults to None.
        cache_behaviors(List, optional): An array of objects that describe the per-path cache behavior for the distribution. Defaults to None.
        bundle_id(str): The bundle ID to use for the distribution. A distribution bundle describes the specifications of your distribution, such as the monthly cost and monthly network transfer quota. Use the GetDistributionBundles action to get a list of distribution bundle IDs that you can specify.
        ip_address_type(str, optional): The IP address type for the distribution. The possible values are ipv4 for IPv4 only, and dualstack for IPv4 and IPv6. The default value is dualstack. Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the distribution during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.init.create(
                ctx,
                distribution_name=value,
                origin=value,
                default_cache_behavior=value,
                bundle_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.init.create distribution_name=value, origin=value, default_cache_behavior=value, bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_distribution",
        op_kwargs={
            "distributionName": distribution_name,
            "origin": origin,
            "defaultCacheBehavior": default_cache_behavior,
            "cacheBehaviorSettings": cache_behavior_settings,
            "cacheBehaviors": cache_behaviors,
            "bundleId": bundle_id,
            "ipAddressType": ip_address_type,
            "tags": tags,
        },
    )


async def delete(hub, ctx, distribution_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes your Amazon Lightsail content delivery network (CDN) distribution.

    Args:
        distribution_name(str, optional): The name of the distribution to delete. Use the GetDistributions action to get a list of distribution names that you can specify. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_distribution",
        op_kwargs={"distributionName": distribution_name},
    )


async def get_all(
    hub, ctx, distribution_name: str = None, page_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more of your Amazon Lightsail content delivery network (CDN) distributions.

    Args:
        distribution_name(str, optional): The name of the distribution for which to return information. When omitted, the response includes all of your distributions in the AWS Region where the request is made. Defaults to None.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetDistributions request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_distributions",
        op_kwargs={"distributionName": distribution_name, "pageToken": page_token},
    )


async def update(
    hub,
    ctx,
    distribution_name: str,
    origin: Dict = None,
    default_cache_behavior: Dict = None,
    cache_behavior_settings: Dict = None,
    cache_behaviors: List = None,
    is_enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Amazon Lightsail content delivery network (CDN) distribution. Use this action to update the configuration of your existing distribution.

    Args:
        distribution_name(str): The name of the distribution to update. Use the GetDistributions action to get a list of distribution names that you can specify.
        origin(Dict, optional): An object that describes the origin resource for the distribution, such as a Lightsail instance or load balancer. The distribution pulls, caches, and serves content from the origin. Defaults to None.
        default_cache_behavior(Dict, optional): An object that describes the default cache behavior for the distribution. Defaults to None.
        cache_behavior_settings(Dict, optional): An object that describes the cache behavior settings for the distribution.  The cacheBehaviorSettings specified in your UpdateDistributionRequest will replace your distribution's existing settings. . Defaults to None.
        cache_behaviors(List, optional): An array of objects that describe the per-path cache behavior for the distribution. Defaults to None.
        is_enabled(bool, optional): Indicates whether to enable the distribution. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.distribution.init.update(ctx, distribution_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.distribution.init.update distribution_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_distribution",
        op_kwargs={
            "distributionName": distribution_name,
            "origin": origin,
            "defaultCacheBehavior": default_cache_behavior,
            "cacheBehaviorSettings": cache_behavior_settings,
            "cacheBehaviors": cache_behaviors,
            "isEnabled": is_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    directory_name: str,
    organizational_unit_distinguished_names: List,
    service_account_credentials: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Directory Config object in AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

    Args:
        directory_name(str): The fully qualified name of the directory (for example, corp.example.com).
        organizational_unit_distinguished_names(List): The distinguished names of the organizational units for computer accounts.
        service_account_credentials(Dict, optional): The credentials for the service account used by the fleet or image builder to connect to the directory. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.directory_config.create(
                ctx, directory_name=value, organizational_unit_distinguished_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.directory_config.create directory_name=value, organizational_unit_distinguished_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="create_directory_config",
        op_kwargs={
            "DirectoryName": directory_name,
            "OrganizationalUnitDistinguishedNames": organizational_unit_distinguished_names,
            "ServiceAccountCredentials": service_account_credentials,
        },
    )


async def delete(hub, ctx, directory_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Directory Config object from AppStream 2.0. This object includes the information required to join streaming instances to an Active Directory domain.

    Args:
        directory_name(str): The name of the directory configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.directory_config.delete(ctx, directory_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.directory_config.delete directory_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_directory_config",
        op_kwargs={"DirectoryName": directory_name},
    )


async def describe_all(
    hub,
    ctx,
    directory_names: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified Directory Config objects for AppStream 2.0, if the names for these objects are provided. Otherwise, all Directory Config objects in the account are described. These objects include the configuration information required to join fleets and image builders to Microsoft Active Directory domains.  Although the response syntax in this topic includes the account password, this password is not returned in the actual response.

    Args:
        directory_names(List, optional): The directory names. Defaults to None.
        max_results(int, optional): The maximum size of each page of results. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.directory_config.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.directory_config.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_directory_configs",
        op_kwargs={
            "DirectoryNames": directory_names,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    directory_name: str,
    organizational_unit_distinguished_names: List = None,
    service_account_credentials: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified Directory Config object in AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

    Args:
        directory_name(str): The name of the Directory Config object.
        organizational_unit_distinguished_names(List, optional): The distinguished names of the organizational units for computer accounts. Defaults to None.
        service_account_credentials(Dict, optional): The credentials for the service account used by the fleet or image builder to connect to the directory. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.directory_config.update(ctx, directory_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.directory_config.update directory_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="update_directory_config",
        op_kwargs={
            "DirectoryName": directory_name,
            "OrganizationalUnitDistinguishedNames": organizational_unit_distinguished_names,
            "ServiceAccountCredentials": service_account_credentials,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, endpoint_arn: str, replication_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the connection between a replication instance and an endpoint.

    Args:
        endpoint_arn(str): The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
        replication_instance_arn(str): The Amazon Resource Name (ARN) of the replication instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.connection.delete(
                ctx, endpoint_arn=value, replication_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.connection.delete endpoint_arn=value, replication_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="delete_connection",
        op_kwargs={
            "EndpointArn": endpoint_arn,
            "ReplicationInstanceArn": replication_instance_arn,
        },
    )


async def describe_all(
    hub, ctx, filters: List = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the status of the connections that have been made between the replication instance and an endpoint. Connections are created when you test an endpoint.

    Args:
        filters(List, optional): The filters applied to the connection. Valid filter names: endpoint-arn | replication-instance-arn. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.connection.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.connection.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_connections",
        op_kwargs={"Filters": filters, "MaxRecords": max_records, "Marker": marker},
    )


async def test(hub, ctx, replication_instance_arn: str, endpoint_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Tests the connection between the replication instance and the endpoint.

    Args:
        replication_instance_arn(str): The Amazon Resource Name (ARN) of the replication instance.
        endpoint_arn(str): The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.connection.test(
                ctx, replication_instance_arn=value, endpoint_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.connection.test replication_instance_arn=value, endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="test_connection",
        op_kwargs={
            "ReplicationInstanceArn": replication_instance_arn,
            "EndpointArn": endpoint_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    engine: str = None,
    engine_version: str = None,
    db_parameter_group_family: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    default_only: bool = None,
    list_supported_character_sets: bool = None,
    list_supported_timezones: bool = None,
    include_all: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the available DB engines.

    Args:
        engine(str, optional): The database engine to return. Valid Values:     aurora (for MySQL 5.6-compatible Aurora)    aurora-mysql (for MySQL 5.7-compatible Aurora)    aurora-postgresql     mariadb     mysql     oracle-ee     oracle-ee-cdb     oracle-se2     oracle-se2-cdb     postgres     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   . Defaults to None.
        engine_version(str, optional): The database engine version to return. Example: 5.1.49 . Defaults to None.
        db_parameter_group_family(str, optional): The name of a specific DB parameter group family to return details for. Constraints:   If supplied, must match an existing DBParameterGroupFamily.  . Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        default_only(bool, optional): A value that indicates whether only the default version of the specified engine or engine and major version combination is returned. Defaults to None.
        list_supported_character_sets(bool, optional): A value that indicates whether to list the supported character sets for each engine version. If this parameter is enabled and the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version. . Defaults to None.
        list_supported_timezones(bool, optional): A value that indicates whether to list the supported time zones for each engine version. If this parameter is enabled and the requested engine supports the TimeZone parameter for CreateDBInstance, the response includes a list of supported time zones for each engine version. . Defaults to None.
        include_all(bool, optional): A value that indicates whether to include engine versions that aren't available in the list. The default is to list only available engine versions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.engine_version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.engine_version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_engine_versions",
        op_kwargs={
            "Engine": engine,
            "EngineVersion": engine_version,
            "DBParameterGroupFamily": db_parameter_group_family,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "DefaultOnly": default_only,
            "ListSupportedCharacterSets": list_supported_character_sets,
            "ListSupportedTimezones": list_supported_timezones,
            "IncludeAll": include_all,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    user_pool_id: str,
    client_name: str,
    generate_secret: bool = None,
    refresh_token_validity: int = None,
    access_token_validity: int = None,
    id_token_validity: int = None,
    token_validity_units: Dict = None,
    read_attributes: List = None,
    write_attributes: List = None,
    explicit_auth_flows: List = None,
    supported_identity_providers: List = None,
    callback_ur_ls: List = None,
    logout_ur_ls: List = None,
    default_redirect_uri: str = None,
    allowed_o_auth_flows: List = None,
    allowed_o_auth_scopes: List = None,
    allowed_o_auth_flows_user_pool_client: bool = None,
    analytics_configuration: Dict = None,
    prevent_user_existence_errors: str = None,
    enable_token_revocation: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates the user pool client. When you create a new user pool client, token revocation is automatically enabled. For more information about revoking tokens, see RevokeToken.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to create a user pool client.
        client_name(str): The client name for the user pool client you would like to create.
        generate_secret(bool, optional): Boolean to specify whether you want to generate a secret for the user pool client being created. Defaults to None.
        refresh_token_validity(int, optional): The time limit, in days, after which the refresh token is no longer valid and cannot be used. Defaults to None.
        access_token_validity(int, optional): The time limit, between 5 minutes and 1 day, after which the access token is no longer valid and cannot be used. This value will be overridden if you have entered a value in TokenValidityUnits. Defaults to None.
        id_token_validity(int, optional): The time limit, between 5 minutes and 1 day, after which the ID token is no longer valid and cannot be used. This value will be overridden if you have entered a value in TokenValidityUnits. Defaults to None.
        token_validity_units(Dict, optional): The units in which the validity times are represented in. Default for RefreshToken is days, and default for ID and access tokens are hours. Defaults to None.
        read_attributes(List, optional): The read attributes. Defaults to None.
        write_attributes(List, optional): The user pool attributes that the app client can write to. If your app client allows users to sign in through an identity provider, this array must include all attributes that are mapped to identity provider attributes. Amazon Cognito updates mapped attributes when users sign in to your application through an identity provider. If your app client lacks write access to a mapped attribute, Amazon Cognito throws an error when it attempts to update the attribute. For more information, see Specifying Identity Provider Attribute Mappings for Your User Pool. Defaults to None.
        explicit_auth_flows(List, optional): The authentication flows that are supported by the user pool clients. Flow names without the ALLOW_ prefix are deprecated in favor of new names with the ALLOW_ prefix. Note that values with ALLOW_ prefix cannot be used along with values without ALLOW_ prefix. Valid values include:    ALLOW_ADMIN_USER_PASSWORD_AUTH: Enable admin based user password authentication flow ADMIN_USER_PASSWORD_AUTH. This setting replaces the ADMIN_NO_SRP_AUTH setting. With this authentication flow, Cognito receives the password in the request instead of using the SRP (Secure Remote Password protocol) protocol to verify passwords.    ALLOW_CUSTOM_AUTH: Enable Lambda trigger based authentication.    ALLOW_USER_PASSWORD_AUTH: Enable user password-based authentication. In this flow, Cognito receives the password in the request instead of using the SRP protocol to verify passwords.    ALLOW_USER_SRP_AUTH: Enable SRP based authentication.    ALLOW_REFRESH_TOKEN_AUTH: Enable authflow to refresh tokens.  . Defaults to None.
        supported_identity_providers(List, optional): A list of provider names for the identity providers that are supported on this client. The following are supported: COGNITO, Facebook, Google and LoginWithAmazon. Defaults to None.
        callback_ur_ls(List, optional): A list of allowed redirect (callback) URLs for the identity providers. A redirect URI must:   Be an absolute URI.   Be registered with the authorization server.   Not include a fragment component.   See OAuth 2.0 - Redirection Endpoint. Amazon Cognito requires HTTPS over HTTP except for http://localhost for testing purposes only. App callback URLs such as myapp://example are also supported. Defaults to None.
        logout_ur_ls(List, optional): A list of allowed logout URLs for the identity providers. Defaults to None.
        default_redirect_uri(str, optional): The default redirect URI. Must be in the CallbackURLs list. A redirect URI must:   Be an absolute URI.   Be registered with the authorization server.   Not include a fragment component.   See OAuth 2.0 - Redirection Endpoint. Amazon Cognito requires HTTPS over HTTP except for http://localhost for testing purposes only. App callback URLs such as myapp://example are also supported. Defaults to None.
        allowed_o_auth_flows(List, optional): The allowed OAuth flows. Set to code to initiate a code grant flow, which provides an authorization code as the response. This code can be exchanged for access tokens with the token endpoint. Set to implicit to specify that the client should get the access token (and, optionally, ID token, based on scopes) directly. Set to client_credentials to specify that the client should get the access token (and, optionally, ID token, based on scopes) from the token endpoint using a combination of client and client_secret. Defaults to None.
        allowed_o_auth_scopes(List, optional): The allowed OAuth scopes. Possible values provided by OAuth are: phone, email, openid, and profile. Possible values provided by Amazon Web Services are: aws.cognito.signin.user.admin. Custom scopes created in Resource Servers are also supported. Defaults to None.
        allowed_o_auth_flows_user_pool_client(bool, optional): Set to true if the client is allowed to follow the OAuth protocol when interacting with Cognito user pools. Defaults to None.
        analytics_configuration(Dict, optional): The Amazon Pinpoint analytics configuration for collecting metrics for this user pool.  In regions where Pinpoint is not available, Cognito User Pools only supports sending events to Amazon Pinpoint projects in us-east-1. In regions where Pinpoint is available, Cognito User Pools will support sending events to Amazon Pinpoint projects within that same region.  . Defaults to None.
        prevent_user_existence_errors(str, optional): Use this setting to choose which errors and responses are returned by Cognito APIs during authentication, account confirmation, and password recovery when the user does not exist in the user pool. When set to ENABLED and the user does not exist, authentication returns an error indicating either the username or password was incorrect, and account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to LEGACY, those APIs will return a UserNotFoundException exception if the user does not exist in the user pool. Valid values include:    ENABLED - This prevents user existence-related errors.    LEGACY - This represents the old behavior of Cognito where user existence related errors are not prevented.    After February 15th 2020, the value of PreventUserExistenceErrors will default to ENABLED for newly created user pool clients if no value is provided. . Defaults to None.
        enable_token_revocation(bool, optional): Enables or disables token revocation. For more information about revoking tokens, see RevokeToken. If you don't include this parameter, token revocation is automatically enabled for the new user pool client. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.client.create(
                ctx, user_pool_id=value, client_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.client.create user_pool_id=value, client_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="create_user_pool_client",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "ClientName": client_name,
            "GenerateSecret": generate_secret,
            "RefreshTokenValidity": refresh_token_validity,
            "AccessTokenValidity": access_token_validity,
            "IdTokenValidity": id_token_validity,
            "TokenValidityUnits": token_validity_units,
            "ReadAttributes": read_attributes,
            "WriteAttributes": write_attributes,
            "ExplicitAuthFlows": explicit_auth_flows,
            "SupportedIdentityProviders": supported_identity_providers,
            "CallbackURLs": callback_ur_ls,
            "LogoutURLs": logout_ur_ls,
            "DefaultRedirectURI": default_redirect_uri,
            "AllowedOAuthFlows": allowed_o_auth_flows,
            "AllowedOAuthScopes": allowed_o_auth_scopes,
            "AllowedOAuthFlowsUserPoolClient": allowed_o_auth_flows_user_pool_client,
            "AnalyticsConfiguration": analytics_configuration,
            "PreventUserExistenceErrors": prevent_user_existence_errors,
            "EnableTokenRevocation": enable_token_revocation,
        },
    )


async def delete(hub, ctx, user_pool_id: str, client_id: str) -> None:
    r"""
    **Autogenerated function**

    Allows the developer to delete the user pool client.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to delete the client.
        client_id(str): The app client ID of the app associated with the user pool.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.client.delete(
                ctx, user_pool_id=value, client_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.client.delete user_pool_id=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="delete_user_pool_client",
        op_kwargs={"UserPoolId": user_pool_id, "ClientId": client_id},
    )


async def describe(hub, ctx, user_pool_id: str, client_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Client method for returning the configuration information and metadata of the specified user pool app client.

    Args:
        user_pool_id(str): The user pool ID for the user pool you want to describe.
        client_id(str): The app client ID of the app associated with the user pool.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.client.describe(
                ctx, user_pool_id=value, client_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.client.describe user_pool_id=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="describe_user_pool_client",
        op_kwargs={"UserPoolId": user_pool_id, "ClientId": client_id},
    )


async def list_all(
    hub, ctx, user_pool_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the clients that have been created for the specified user pool.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to list user pool clients.
        max_results(int, optional): The maximum number of results you want the request to return when listing the user pool clients. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.client.list_all(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.client.list_all user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_user_pool_clients",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    user_pool_id: str,
    client_id: str,
    client_name: str = None,
    refresh_token_validity: int = None,
    access_token_validity: int = None,
    id_token_validity: int = None,
    token_validity_units: Dict = None,
    read_attributes: List = None,
    write_attributes: List = None,
    explicit_auth_flows: List = None,
    supported_identity_providers: List = None,
    callback_ur_ls: List = None,
    logout_ur_ls: List = None,
    default_redirect_uri: str = None,
    allowed_o_auth_flows: List = None,
    allowed_o_auth_scopes: List = None,
    allowed_o_auth_flows_user_pool_client: bool = None,
    analytics_configuration: Dict = None,
    prevent_user_existence_errors: str = None,
    enable_token_revocation: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified user pool app client with the specified attributes. You can get a list of the current user pool app client settings using DescribeUserPoolClient.  If you don't provide a value for an attribute, it will be set to the default value.  You can also use this operation to enable token revocation for user pool clients. For more information about revoking tokens, see RevokeToken.

    Args:
        user_pool_id(str): The user pool ID for the user pool where you want to update the user pool client.
        client_id(str): The ID of the client associated with the user pool.
        client_name(str, optional): The client name from the update user pool client request. Defaults to None.
        refresh_token_validity(int, optional): The time limit, in days, after which the refresh token is no longer valid and cannot be used. Defaults to None.
        access_token_validity(int, optional): The time limit, after which the access token is no longer valid and cannot be used. Defaults to None.
        id_token_validity(int, optional): The time limit, after which the ID token is no longer valid and cannot be used. Defaults to None.
        token_validity_units(Dict, optional): The units in which the validity times are represented in. Default for RefreshToken is days, and default for ID and access tokens are hours. Defaults to None.
        read_attributes(List, optional): The read-only attributes of the user pool. Defaults to None.
        write_attributes(List, optional): The writeable attributes of the user pool. Defaults to None.
        explicit_auth_flows(List, optional): The authentication flows that are supported by the user pool clients. Flow names without the ALLOW_ prefix are deprecated in favor of new names with the ALLOW_ prefix. Note that values with ALLOW_ prefix cannot be used along with values without ALLOW_ prefix. Valid values include:    ALLOW_ADMIN_USER_PASSWORD_AUTH: Enable admin based user password authentication flow ADMIN_USER_PASSWORD_AUTH. This setting replaces the ADMIN_NO_SRP_AUTH setting. With this authentication flow, Cognito receives the password in the request instead of using the SRP (Secure Remote Password protocol) protocol to verify passwords.    ALLOW_CUSTOM_AUTH: Enable Lambda trigger based authentication.    ALLOW_USER_PASSWORD_AUTH: Enable user password-based authentication. In this flow, Cognito receives the password in the request instead of using the SRP protocol to verify passwords.    ALLOW_USER_SRP_AUTH: Enable SRP based authentication.    ALLOW_REFRESH_TOKEN_AUTH: Enable authflow to refresh tokens.  . Defaults to None.
        supported_identity_providers(List, optional): A list of provider names for the identity providers that are supported on this client. Defaults to None.
        callback_ur_ls(List, optional): A list of allowed redirect (callback) URLs for the identity providers. A redirect URI must:   Be an absolute URI.   Be registered with the authorization server.   Not include a fragment component.   See OAuth 2.0 - Redirection Endpoint. Amazon Cognito requires HTTPS over HTTP except for http://localhost for testing purposes only. App callback URLs such as myapp://example are also supported. Defaults to None.
        logout_ur_ls(List, optional): A list of allowed logout URLs for the identity providers. Defaults to None.
        default_redirect_uri(str, optional): The default redirect URI. Must be in the CallbackURLs list. A redirect URI must:   Be an absolute URI.   Be registered with the authorization server.   Not include a fragment component.   See OAuth 2.0 - Redirection Endpoint. Amazon Cognito requires HTTPS over HTTP except for http://localhost for testing purposes only. App callback URLs such as myapp://example are also supported. Defaults to None.
        allowed_o_auth_flows(List, optional): The allowed OAuth flows. Set to code to initiate a code grant flow, which provides an authorization code as the response. This code can be exchanged for access tokens with the token endpoint. Set to implicit to specify that the client should get the access token (and, optionally, ID token, based on scopes) directly. Set to client_credentials to specify that the client should get the access token (and, optionally, ID token, based on scopes) from the token endpoint using a combination of client and client_secret. Defaults to None.
        allowed_o_auth_scopes(List, optional): The allowed OAuth scopes. Possible values provided by OAuth are: phone, email, openid, and profile. Possible values provided by Amazon Web Services are: aws.cognito.signin.user.admin. Custom scopes created in Resource Servers are also supported. Defaults to None.
        allowed_o_auth_flows_user_pool_client(bool, optional): Set to true if the client is allowed to follow the OAuth protocol when interacting with Cognito user pools. Defaults to None.
        analytics_configuration(Dict, optional): The Amazon Pinpoint analytics configuration for collecting metrics for this user pool.  In regions where Pinpoint is not available, Cognito User Pools only supports sending events to Amazon Pinpoint projects in us-east-1. In regions where Pinpoint is available, Cognito User Pools will support sending events to Amazon Pinpoint projects within that same region.  . Defaults to None.
        prevent_user_existence_errors(str, optional): Use this setting to choose which errors and responses are returned by Cognito APIs during authentication, account confirmation, and password recovery when the user does not exist in the user pool. When set to ENABLED and the user does not exist, authentication returns an error indicating either the username or password was incorrect, and account confirmation and password recovery return a response indicating a code was sent to a simulated destination. When set to LEGACY, those APIs will return a UserNotFoundException exception if the user does not exist in the user pool. Valid values include:    ENABLED - This prevents user existence-related errors.    LEGACY - This represents the old behavior of Cognito where user existence related errors are not prevented.    After February 15th 2020, the value of PreventUserExistenceErrors will default to ENABLED for newly created user pool clients if no value is provided. . Defaults to None.
        enable_token_revocation(bool, optional): Enables or disables token revocation. For more information about revoking tokens, see RevokeToken. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.client.update(
                ctx, user_pool_id=value, client_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.client.update user_pool_id=value, client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_user_pool_client",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "ClientId": client_id,
            "ClientName": client_name,
            "RefreshTokenValidity": refresh_token_validity,
            "AccessTokenValidity": access_token_validity,
            "IdTokenValidity": id_token_validity,
            "TokenValidityUnits": token_validity_units,
            "ReadAttributes": read_attributes,
            "WriteAttributes": write_attributes,
            "ExplicitAuthFlows": explicit_auth_flows,
            "SupportedIdentityProviders": supported_identity_providers,
            "CallbackURLs": callback_ur_ls,
            "LogoutURLs": logout_ur_ls,
            "DefaultRedirectURI": default_redirect_uri,
            "AllowedOAuthFlows": allowed_o_auth_flows,
            "AllowedOAuthScopes": allowed_o_auth_scopes,
            "AllowedOAuthFlowsUserPoolClient": allowed_o_auth_flows_user_pool_client,
            "AnalyticsConfiguration": analytics_configuration,
            "PreventUserExistenceErrors": prevent_user_existence_errors,
            "EnableTokenRevocation": enable_token_revocation,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, configuration_ids: List, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more tags for configuration items. Tags are metadata that help you categorize IT assets. This API accepts a list of multiple configuration items.

    Args:
        configuration_ids(List): A list of configuration items that you want to tag.
        tags(List): Tags that you want to associate with one or more configuration items. Specify the tags that you want to create in a key-value format. For example:  {"key": "serverType", "value": "webServer"} .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.tags.create(ctx, configuration_ids=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.tags.create configuration_ids=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="create_tags",
        op_kwargs={"configurationIds": configuration_ids, "tags": tags},
    )


async def delete(hub, ctx, configuration_ids: List, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the association between configuration items and one or more tags. This API accepts a list of multiple configuration items.

    Args:
        configuration_ids(List): A list of configuration items with tags that you want to delete.
        tags(List, optional): Tags that you want to delete from one or more configuration items. Specify the tags that you want to delete in a key-value format. For example:  {"key": "serverType", "value": "webServer"} . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.tags.delete(ctx, configuration_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.tags.delete configuration_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="delete_tags",
        op_kwargs={"configurationIds": configuration_ids, "tags": tags},
    )


async def describe(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of configuration items that have tags as specified by the key-value pairs, name and value, passed to the optional parameter filters. There are three valid tag filter names:   tagKey   tagValue   configurationId   Also, all configuration items associated with your user account that have tags can be listed if you call DescribeTags as is without passing any parameters.

    Args:
        filters(List, optional): You can filter the list using a key-value format. You can separate these items by using logical operators. Allowed filters include tagKey, tagValue, and configurationId. . Defaults to None.
        max_results(int, optional): The total number of items to return in a single page of output. The maximum value is 100. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.tags.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.tags.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="describe_tags",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, voice_connector_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the streaming configuration for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.streaming_configuration.delete(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.streaming_configuration.delete voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_voice_connector_streaming_configuration",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the streaming configuration details for the specified Amazon Chime Voice Connector. Shows whether media streaming is enabled for sending to Amazon Kinesis. It also shows the retention period, in hours, for the Amazon Kinesis data.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.streaming_configuration.get(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.streaming_configuration.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_streaming_configuration",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def put(hub, ctx, voice_connector_id: str, streaming_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds a streaming configuration for the specified Amazon Chime Voice Connector. The streaming configuration specifies whether media streaming is enabled for sending to Indonesians. It also sets the retention period, in hours, for the Amazon Kinesis data.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
        streaming_configuration(Dict): The streaming configuration details to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.streaming_configuration.put(
                ctx, voice_connector_id=value, streaming_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.streaming_configuration.put voice_connector_id=value, streaming_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_voice_connector_streaming_configuration",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "StreamingConfiguration": streaming_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    resource_config: Dict,
    resource_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new backend API resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict): The resource configuration for this request.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.api.init.create(
                ctx,
                app_id=value,
                backend_environment_name=value,
                resource_config=value,
                resource_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.api.init.create app_id=value, backend_environment_name=value, resource_config=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="create_backend_api",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )


async def delete(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    resource_name: str,
    resource_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing backend API resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict, optional): Defines the resource configuration for the data model in your Amplify project. Defaults to None.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.api.init.delete(
                ctx, app_id=value, backend_environment_name=value, resource_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.api.init.delete app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="delete_backend_api",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )


async def get(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    resource_name: str,
    resource_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the details for a backend API.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict, optional): Defines the resource configuration for the data model in your Amplify project. Defaults to None.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.api.init.get(
                ctx, app_id=value, backend_environment_name=value, resource_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.api.init.get app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="get_backend_api",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )


async def update(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    resource_name: str,
    resource_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing backend API resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict, optional): Defines the resource configuration for the data model in your Amplify project. Defaults to None.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.api.init.update(
                ctx, app_id=value, backend_environment_name=value, resource_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.api.init.update app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="update_backend_api",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def describe(
    hub, ctx, code_review_arn: str, recommendation_id: str, user_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Describes the customer feedback for a CodeGuru Reviewer recommendation.

    Args:
        code_review_arn(str): The Amazon Resource Name (ARN) of the  CodeReview  object. .
        recommendation_id(str):  The recommendation ID that can be used to track the provided recommendations and then to collect the feedback. .
        user_id(str, optional):  Optional parameter to describe the feedback for a given user. If this is not supplied, it defaults to the user making the request.   The UserId is an IAM principal that can be specified as an AWS account ID or an Amazon Resource Name (ARN). For more information, see  Specifying a Principal in the AWS Identity and Access Management User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.recommendation.feedback.describe(
                ctx, code_review_arn=value, recommendation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.recommendation.feedback.describe code_review_arn=value, recommendation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="describe_recommendation_feedback",
        op_kwargs={
            "CodeReviewArn": code_review_arn,
            "RecommendationId": recommendation_id,
            "UserId": user_id,
        },
    )


async def list_(
    hub,
    ctx,
    code_review_arn: str,
    next_token: str = None,
    max_results: int = None,
    user_ids: List = None,
    recommendation_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of  RecommendationFeedbackSummary  objects that contain customer recommendation feedback for all CodeGuru Reviewer users.

    Args:
        next_token(str, optional):  If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. . Defaults to None.
        max_results(int, optional):  The maximum number of results that are returned per call. The default is 100. . Defaults to None.
        code_review_arn(str): The Amazon Resource Name (ARN) of the  CodeReview  object. .
        user_ids(List, optional):  An AWS user's account ID or Amazon Resource Name (ARN). Use this ID to query the recommendation feedback for a code review from that user.   The UserId is an IAM principal that can be specified as an AWS account ID or an Amazon Resource Name (ARN). For more information, see  Specifying a Principal in the AWS Identity and Access Management User Guide. . Defaults to None.
        recommendation_ids(List, optional):  Used to query the recommendation feedback for a given recommendation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.recommendation.feedback.list(
                ctx, code_review_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.recommendation.feedback.list code_review_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="list_recommendation_feedback",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CodeReviewArn": code_review_arn,
            "UserIds": user_ids,
            "RecommendationIds": recommendation_ids,
        },
    )


async def put(
    hub, ctx, code_review_arn: str, recommendation_id: str, reactions: List
) -> Dict:
    r"""
    **Autogenerated function**

     Stores customer feedback for a CodeGuru Reviewer recommendation. When this API is called again with different reactions the previous feedback is overwritten.

    Args:
        code_review_arn(str): The Amazon Resource Name (ARN) of the  CodeReview  object. .
        recommendation_id(str):  The recommendation ID that can be used to track the provided recommendations and then to collect the feedback. .
        reactions(List):  List for storing reactions. Reactions are utf-8 text code for emojis. If you send an empty list it clears all your feedback. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.recommendation.feedback.put(
                ctx, code_review_arn=value, recommendation_id=value, reactions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.recommendation.feedback.put code_review_arn=value, recommendation_id=value, reactions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="put_recommendation_feedback",
        op_kwargs={
            "CodeReviewArn": code_review_arn,
            "RecommendationId": recommendation_id,
            "Reactions": reactions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts the recording of AWS API calls and log file delivery for a trail. For a trail that is enabled in all regions, this operation must be called from the region in which the trail was created. This operation cannot be called on the shadow trails (replicated trails in other regions) of a trail that is enabled in all regions.

    Args:
        name(str): Specifies the name or the CloudTrail ARN of the trail for which CloudTrail logs AWS API calls. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.logging.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.logging.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="start_logging",
        op_kwargs={"Name": name},
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Suspends the recording of AWS API calls and log file delivery for the specified trail. Under most circumstances, there is no need to use this action. You can update a trail without stopping it first. This action is the only way to stop recording. For a trail enabled in all regions, this operation must be called from the region in which the trail was created, or an InvalidHomeRegionException will occur. This operation cannot be called on the shadow trails (replicated trails in other regions) of a trail enabled in all regions.

    Args:
        name(str): Specifies the name or the CloudTrail ARN of the trail for which CloudTrail will stop logging AWS API calls. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.logging.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.logging.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="stop_logging",
        op_kwargs={"Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def publish(
    hub,
    ctx,
    message: str,
    topic_arn: str = None,
    target_arn: str = None,
    phone_number: str = None,
    subject: str = None,
    message_structure: str = None,
    message_attributes: Dict = None,
    message_deduplication_id: str = None,
    message_group_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a message to an Amazon SNS topic, a text message (SMS message) directly to a phone number, or a message to a mobile platform endpoint (when you specify the TargetArn). If you send a message to a topic, Amazon SNS delivers the message to each endpoint that is subscribed to the topic. The format of the message depends on the notification protocol for each subscribed endpoint. When a messageId is returned, the message has been saved and Amazon SNS will attempt to deliver it shortly. To use the Publish action for sending a message to a mobile endpoint, such as an app on a Kindle device or mobile phone, you must specify the EndpointArn for the TargetArn parameter. The EndpointArn is returned when making a call with the CreatePlatformEndpoint action.  For more information about formatting messages, see Send Custom Platform-Specific Payloads in Messages to Mobile Devices.   You can publish messages only to topics and endpoints in the same Region.

    Args:
        topic_arn(str, optional): The topic you want to publish to. If you don't specify a value for the TopicArn parameter, you must specify a value for the PhoneNumber or TargetArn parameters. Defaults to None.
        target_arn(str, optional): If you don't specify a value for the TargetArn parameter, you must specify a value for the PhoneNumber or TopicArn parameters. Defaults to None.
        phone_number(str, optional): The phone number to which you want to deliver an SMS message. Use E.164 format. If you don't specify a value for the PhoneNumber parameter, you must specify a value for the TargetArn or TopicArn parameters. Defaults to None.
        message(str): The message you want to send. If you are publishing to a topic and you want to send the same message to all transport protocols, include the text of the message as a String value. If you want to send different messages for each transport protocol, set the value of the MessageStructure parameter to json and use a JSON object for the Message parameter.   Constraints:   With the exception of SMS, messages must be UTF-8 encoded strings and at most 256 KB in size (262,144 bytes, not 262,144 characters).   For SMS, each message can contain up to 140 characters. This character limit depends on the encoding schema. For example, an SMS message can contain 160 GSM characters, 140 ASCII characters, or 70 UCS-2 characters. If you publish a message that exceeds this size limit, Amazon SNS sends the message as multiple messages, each fitting within the size limit. Messages aren't truncated mid-word but are cut off at whole-word boundaries. The total size limit for a single SMS Publish action is 1,600 characters.   JSON-specific constraints:   Keys in the JSON object that correspond to supported transport protocols must have simple JSON string values.   The values will be parsed (unescaped) before they are used in outgoing messages.   Outbound notifications are JSON encoded (meaning that the characters will be reescaped for sending).   Values have a minimum length of 0 (the empty string, "", is allowed).   Values have a maximum length bounded by the overall message size (so, including multiple protocols may limit message sizes).   Non-string values will cause the key to be ignored.   Keys that do not correspond to supported transport protocols are ignored.   Duplicate keys are not allowed.   Failure to parse or validate any key or value in the message will cause the Publish call to return an error (no partial delivery).  .
        subject(str, optional): Optional parameter to be used as the "Subject" line when the message is delivered to email endpoints. This field will also be included, if present, in the standard JSON messages delivered to other endpoints. Constraints: Subjects must be ASCII text that begins with a letter, number, or punctuation mark; must not include line breaks or control characters; and must be less than 100 characters long. Defaults to None.
        message_structure(str, optional): Set MessageStructure to json if you want to send a different message for each protocol. For example, using one publish action, you can send a short message to your SMS subscribers and a longer message to your email subscribers. If you set MessageStructure to json, the value of the Message parameter must:    be a syntactically valid JSON object; and   contain at least a top-level JSON key of "default" with a value that is a string.   You can define other top-level keys that define the message you want to send to a specific transport protocol (e.g., "http"). Valid value: json . Defaults to None.
        message_attributes(Dict, optional): Message attributes for Publish action. Defaults to None.
        message_deduplication_id(str, optional): This parameter applies only to FIFO (first-in-first-out) topics. The MessageDeduplicationId can contain up to 128 alphanumeric characters (a-z, A-Z, 0-9) and punctuation (!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~). Every message must have a unique MessageDeduplicationId, which is a token used for deduplication of sent messages. If a message with a particular MessageDeduplicationId is sent successfully, any message sent with the same MessageDeduplicationId during the 5-minute deduplication interval is treated as a duplicate.  If the topic has ContentBasedDeduplication set, the system generates a MessageDeduplicationId based on the contents of the message. Your MessageDeduplicationId overrides the generated one. Defaults to None.
        message_group_id(str, optional): This parameter applies only to FIFO (first-in-first-out) topics. The MessageGroupId can contain up to 128 alphanumeric characters (a-z, A-Z, 0-9) and punctuation (!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~). The MessageGroupId is a tag that specifies that a message belongs to a specific message group. Messages that belong to the same message group are processed in a FIFO manner (however, messages in different message groups might be processed out of order). Every message must include a MessageGroupId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.init.publish(ctx, message=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.init.publish message=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="publish",
        op_kwargs={
            "TopicArn": topic_arn,
            "TargetArn": target_arn,
            "PhoneNumber": phone_number,
            "Message": message,
            "Subject": subject,
            "MessageStructure": message_structure,
            "MessageAttributes": message_attributes,
            "MessageDeduplicationId": message_deduplication_id,
            "MessageGroupId": message_group_id,
        },
    )


async def subscribe(
    hub,
    ctx,
    topic_arn: str,
    protocol: str,
    endpoint: str = None,
    attributes: Dict = None,
    return_subscription_arn: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Subscribes an endpoint to an Amazon SNS topic. If the endpoint type is HTTP/S or email, or if the endpoint and the topic are not in the same account, the endpoint owner must run the ConfirmSubscription action to confirm the subscription. You call the ConfirmSubscription action with the token from the subscription response. Confirmation tokens are valid for three days. This action is throttled at 100 transactions per second (TPS).

    Args:
        topic_arn(str): The ARN of the topic you want to subscribe to.
        protocol(str): The protocol that you want to use. Supported protocols include:    http – delivery of JSON-encoded message via HTTP POST    https – delivery of JSON-encoded message via HTTPS POST    email – delivery of message via SMTP    email-json – delivery of JSON-encoded message via SMTP    sms – delivery of message via SMS    sqs – delivery of JSON-encoded message to an Amazon SQS queue    application – delivery of JSON-encoded message to an EndpointArn for a mobile app and device    lambda – delivery of JSON-encoded message to an Lambda function    firehose – delivery of JSON-encoded message to an Amazon Kinesis Data Firehose delivery stream.  .
        endpoint(str, optional): The endpoint that you want to receive notifications. Endpoints vary by protocol:   For the http protocol, the (public) endpoint is a URL beginning with http://.   For the https protocol, the (public) endpoint is a URL beginning with https://.   For the email protocol, the endpoint is an email address.   For the email-json protocol, the endpoint is an email address.   For the sms protocol, the endpoint is a phone number of an SMS-enabled device.   For the sqs protocol, the endpoint is the ARN of an Amazon SQS queue.   For the application protocol, the endpoint is the EndpointArn of a mobile app and device.   For the lambda protocol, the endpoint is the ARN of an Lambda function.   For the firehose protocol, the endpoint is the ARN of an Amazon Kinesis Data Firehose delivery stream.  . Defaults to None.
        attributes(Dict, optional): A map of attributes with their corresponding values. The following lists the names, descriptions, and values of the special request parameters that the Subscribe action uses:    DeliveryPolicy – The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints.    FilterPolicy – The simple JSON object that lets your subscriber receive only a subset of messages, rather than receiving every message published to the topic.    RawMessageDelivery – When set to true, enables raw message delivery to Amazon SQS or HTTP/S endpoints. This eliminates the need for the endpoints to process JSON formatting, which is otherwise created for Amazon SNS metadata.    RedrivePolicy – When specified, sends undeliverable messages to the specified Amazon SQS dead-letter queue. Messages that can't be delivered due to client errors (for example, when the subscribed endpoint is unreachable) or server errors (for example, when the service that powers the subscribed endpoint becomes unavailable) are held in the dead-letter queue for further analysis or reprocessing.   The following attribute applies only to Amazon Kinesis Data Firehose delivery stream subscriptions:    SubscriptionRoleArn – The ARN of the IAM role that has the following:   Permission to write to the Kinesis Data Firehose delivery stream   Amazon SNS listed as a trusted entity   Specifying a valid ARN for this attribute is required for Kinesis Data Firehose delivery stream subscriptions. For more information, see Fanout to Kinesis Data Firehose delivery streams in the Amazon SNS Developer Guide.  . Defaults to None.
        return_subscription_arn(bool, optional): Sets whether the response from the Subscribe request includes the subscription ARN, even if the subscription is not yet confirmed. If you set this parameter to true, the response includes the ARN in all cases, even if the subscription is not yet confirmed. In addition to the ARN for confirmed subscriptions, the response also includes the pending subscription ARN value for subscriptions that aren't yet confirmed. A subscription becomes confirmed when the subscriber calls the ConfirmSubscription action with a confirmation token.  The default value is false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.init.subscribe(ctx, topic_arn=value, protocol=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.init.subscribe topic_arn=value, protocol=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="subscribe",
        op_kwargs={
            "TopicArn": topic_arn,
            "Protocol": protocol,
            "Endpoint": endpoint,
            "Attributes": attributes,
            "ReturnSubscriptionArn": return_subscription_arn,
        },
    )


async def unsubscribe(hub, ctx, subscription_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a subscription. If the subscription requires authentication for deletion, only the owner of the subscription or the topic's owner can unsubscribe, and an Amazon Web Services signature is required. If the Unsubscribe call does not require authentication and the requester is not the subscription owner, a final cancellation message is delivered to the endpoint, so that the endpoint owner can easily resubscribe to the topic if the Unsubscribe request was unintended. This action is throttled at 100 transactions per second (TPS).

    Args:
        subscription_arn(str): The ARN of the subscription to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.init.unsubscribe(ctx, subscription_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.init.unsubscribe subscription_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="unsubscribe",
        op_kwargs={"SubscriptionArn": subscription_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    project_name: str = None,
    filter_: Dict = None,
    max_results: int = None,
    sort_order: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the identifiers of the build batches for a specific project.

    Args:
        project_name(str, optional): The name of the project. Defaults to None.
        filter_(Dict, optional): A BuildBatchFilter object that specifies the filters for the search. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        sort_order(str, optional): Specifies the sort order of the returned items. Valid values include:    ASCENDING: List the batch build identifiers in ascending order by identifier.    DESCENDING: List the batch build identifiers in descending order by identifier.  . Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous call to ListBuildBatchesForProject. This specifies the next item to return. To return the beginning of the list, exclude this parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.build.batch.for_project.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.build.batch.for_project.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_build_batches_for_project",
        op_kwargs={
            "projectName": project_name,
            "filter": filter_,
            "maxResults": max_results,
            "sortOrder": sort_order,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    first_slot_start_time_range: Dict,
    recurrence: Dict,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    max_slot_duration_in_hours: int = None,
    min_slot_duration_in_hours: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Finds available schedules that meet the specified criteria. You can search for an available schedule no more than 3 months in advance. You must meet the minimum required duration of 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours. After you find a schedule that meets your needs, call PurchaseScheduledInstances to purchase Scheduled Instances with that schedule.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): The filters.    availability-zone - The Availability Zone (for example, us-west-2a).    instance-type - The instance type (for example, c4.large).    network-platform - The network platform (EC2-Classic or EC2-VPC).    platform - The platform (Linux/UNIX or Windows).  . Defaults to None.
        first_slot_start_time_range(Dict): The time period for the first schedule to start.
        max_results(int, optional): The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 300. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        max_slot_duration_in_hours(int, optional): The maximum available duration, in hours. This value must be greater than MinSlotDurationInHours and less than 1,720. Defaults to None.
        min_slot_duration_in_hours(int, optional): The minimum available duration, in hours. The minimum required duration is 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        recurrence(Dict): The schedule recurrence.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.scheduled_instance.availability.describe(
                ctx, first_slot_start_time_range=value, recurrence=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.scheduled_instance.availability.describe first_slot_start_time_range=value, recurrence=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_scheduled_instance_availability",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "FirstSlotStartTimeRange": first_slot_start_time_range,
            "MaxResults": max_results,
            "MaxSlotDurationInHours": max_slot_duration_in_hours,
            "MinSlotDurationInHours": min_slot_duration_in_hours,
            "NextToken": next_token,
            "Recurrence": recurrence,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    transport_transit_gateway_attachment_id: str,
    options: Dict,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Connect attachment from a specified transit gateway attachment. A Connect attachment is a GRE-based tunnel attachment that you can use to establish a connection between a transit gateway and an appliance. A Connect attachment uses an existing VPC or AWS Direct Connect attachment as the underlying transport mechanism.

    Args:
        transport_transit_gateway_attachment_id(str): The ID of the transit gateway attachment. You can specify a VPC attachment or a AWS Direct Connect attachment.
        options(Dict): The Connect attachment options.
        tag_specifications(List, optional): The tags to apply to the Connect attachment. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.connect.init.create(
                ctx, transport_transit_gateway_attachment_id=value, options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.connect.init.create transport_transit_gateway_attachment_id=value, options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_connect",
        op_kwargs={
            "TransportTransitGatewayAttachmentId": transport_transit_gateway_attachment_id,
            "Options": options,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, transit_gateway_attachment_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Connect attachment. You must first delete any Connect peers for the attachment.

    Args:
        transit_gateway_attachment_id(str): The ID of the Connect attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.connect.init.delete(
                ctx, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.connect.init.delete transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_connect",
        op_kwargs={
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_attachment_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more Connect attachments.

    Args:
        transit_gateway_attachment_ids(List, optional): The IDs of the attachments. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    options.protocol - The tunnel protocol (gre).    state - The state of the attachment (initiating | initiatingRequest | pendingAcceptance | rollingBack | pending | available | modifying | deleting | deleted | failed | rejected | rejecting | failing).    transit-gateway-attachment-id - The ID of the Connect attachment.    transit-gateway-id - The ID of the transit gateway.    transport-transit-gateway-attachment-id - The ID of the transit gateway attachment from which the Connect attachment was created.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.connect.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.connect.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_connects",
        op_kwargs={
            "TransitGatewayAttachmentIds": transit_gateway_attachment_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update_multiple(
    hub, ctx, hit_type_id: str, notification: Dict = None, active: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

     The UpdateNotificationSettings operation creates, updates, disables or re-enables notifications for a HIT type. If you call the UpdateNotificationSettings operation for a HIT type that already has a notification specification, the operation replaces the old specification with a new one. You can call the UpdateNotificationSettings operation to enable or disable notifications for the HIT type, without having to modify the notification specification itself by providing updates to the Active status without specifying a new notification specification. To change the Active status of a HIT type's notifications, the HIT type must already have a notification specification, or one must be provided in the same call to UpdateNotificationSettings.

    Args:
        hit_type_id(str):  The ID of the HIT type whose notification specification is being updated. .
        notification(Dict, optional):  The notification specification for the HIT type. . Defaults to None.
        active(bool, optional):  Specifies whether notifications are sent for HITs of this HIT type, according to the notification specification. You must specify either the Notification parameter or the Active parameter for the call to UpdateNotificationSettings to succeed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.notification_setting.update_multiple(
                ctx, hit_type_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.notification_setting.update_multiple hit_type_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="update_notification_settings",
        op_kwargs={
            "HITTypeId": hit_type_id,
            "Notification": notification,
            "Active": active,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, job_id: str, shipping_option: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a shipping label that will be used to return the Snow device to AWS.

    Args:
        job_id(str): The ID for a job that you want to create the return shipping label for; for example, JID123e4567-e89b-12d3-a456-426655440000.
        shipping_option(str, optional): The shipping speed for a particular job. This speed doesn't dictate how soon the device is returned to AWS. This speed represents how quickly it moves to its destination while in transit. Regional shipping speeds are as follows:. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.return_shipping_label.create(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.return_shipping_label.create job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="create_return_shipping_label",
        op_kwargs={"JobId": job_id, "ShippingOption": shipping_option},
    )


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Information on the shipping label of a Snow device that is being returned to AWS.

    Args:
        job_id(str): The automatically generated ID for a job, for example JID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.return_shipping_label.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.return_shipping_label.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="describe_return_shipping_label",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of offering promotions. Each offering promotion record contains the ID and description of the promotion. The API returns a NotEligible error if the caller is not permitted to invoke the operation. Contact aws-devicefarm-support@amazon.com if you must be able to invoke this operation.

    Args:
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.offering.promotion.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.offering.promotion.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_offering_promotions",
        op_kwargs={"nextToken": next_token},
    )
